# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: air/AirQuality.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import FeedHeader_pb2 as FeedHeader__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='air/AirQuality.proto',
  package='air_quality',
  syntax='proto3',
  serialized_options=b'\n\025io.pravah.air.quality',
  serialized_pb=b'\n\x14\x61ir/AirQuality.proto\x12\x0b\x61ir_quality\x1a\x10\x46\x65\x65\x64Header.proto\"V\n\x0b\x46\x65\x65\x64Message\x12\x1b\n\x06header\x18\x01 \x01(\x0b\x32\x0b.FeedHeader\x12*\n\x08stations\x18\x02 \x03(\x0b\x32\x18.air_quality.FeedStation\"V\n\x0b\x46\x65\x65\x64Station\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12(\n\x08\x64\x61taList\x18\x03 \x03(\x0b\x32\x16.air_quality.DataPoint\"\xcc\x02\n\tDataPoint\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.air_quality.DataPoint.Type\x12\r\n\x05value\x18\x02 \x01(\x01\x12!\n\x05\x65rror\x18\x03 \x03(\x0b\x32\x12.air_quality.Error\x12\x11\n\ttimestamp\x18\x04 \x01(\x04\"\xce\x01\n\x04Type\x12\t\n\x05PM2_5\x10\x00\x12\x08\n\x04PM10\x10\x01\x12\x06\n\x02NO\x10\x02\x12\x07\n\x03NO2\x10\x03\x12\x07\n\x03NOX\x10\x04\x12\x07\n\x03NH3\x10\x05\x12\x07\n\x03SO2\x10\x06\x12\x06\n\x02\x43O\x10\x07\x12\t\n\x05OZONE\x10\x08\x12\x0b\n\x07\x42\x45NZENE\x10\t\x12\x0b\n\x07TOLUENE\x10\n\x12\x08\n\x04TEMP\x10\x0b\x12\x06\n\x02RH\x10\x0c\x12\x06\n\x02WS\x10\r\x12\x06\n\x02WD\x10\x0e\x12\x06\n\x02\x42P\x10\x0f\x12\r\n\tMP_XYLENE\x10\x10\x12\x06\n\x02SR\x10\x11\x12\x06\n\x02RF\x10\x12\x12\x0f\n\x0b\x45TH_BENZENE\x10\x13\"$\n\x05\x45rror\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x42\x17\n\x15io.pravah.air.qualityb\x06proto3'
  ,
  dependencies=[FeedHeader__pb2.DESCRIPTOR,])



_DATAPOINT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='air_quality.DataPoint.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PM2_5', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PM10', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO2', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOX', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NH3', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SO2', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CO', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OZONE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BENZENE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOLUENE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMP', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RH', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WD', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BP', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP_XYLENE', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SR', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RF', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ETH_BENZENE', index=19, number=19,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=358,
  serialized_end=564,
)
_sym_db.RegisterEnumDescriptor(_DATAPOINT_TYPE)


_FEEDMESSAGE = _descriptor.Descriptor(
  name='FeedMessage',
  full_name='air_quality.FeedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='air_quality.FeedMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stations', full_name='air_quality.FeedMessage.stations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=141,
)


_FEEDSTATION = _descriptor.Descriptor(
  name='FeedStation',
  full_name='air_quality.FeedStation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='air_quality.FeedStation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='air_quality.FeedStation.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataList', full_name='air_quality.FeedStation.dataList', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=229,
)


_DATAPOINT = _descriptor.Descriptor(
  name='DataPoint',
  full_name='air_quality.DataPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='air_quality.DataPoint.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='air_quality.DataPoint.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='air_quality.DataPoint.error', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='air_quality.DataPoint.timestamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATAPOINT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=564,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='air_quality.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='air_quality.Error.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='air_quality.Error.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=602,
)

_FEEDMESSAGE.fields_by_name['header'].message_type = FeedHeader__pb2._FEEDHEADER
_FEEDMESSAGE.fields_by_name['stations'].message_type = _FEEDSTATION
_FEEDSTATION.fields_by_name['dataList'].message_type = _DATAPOINT
_DATAPOINT.fields_by_name['type'].enum_type = _DATAPOINT_TYPE
_DATAPOINT.fields_by_name['error'].message_type = _ERROR
_DATAPOINT_TYPE.containing_type = _DATAPOINT
DESCRIPTOR.message_types_by_name['FeedMessage'] = _FEEDMESSAGE
DESCRIPTOR.message_types_by_name['FeedStation'] = _FEEDSTATION
DESCRIPTOR.message_types_by_name['DataPoint'] = _DATAPOINT
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMessage = _reflection.GeneratedProtocolMessageType('FeedMessage', (_message.Message,), {
  'DESCRIPTOR' : _FEEDMESSAGE,
  '__module__' : 'air.AirQuality_pb2'
  # @@protoc_insertion_point(class_scope:air_quality.FeedMessage)
  })
_sym_db.RegisterMessage(FeedMessage)

FeedStation = _reflection.GeneratedProtocolMessageType('FeedStation', (_message.Message,), {
  'DESCRIPTOR' : _FEEDSTATION,
  '__module__' : 'air.AirQuality_pb2'
  # @@protoc_insertion_point(class_scope:air_quality.FeedStation)
  })
_sym_db.RegisterMessage(FeedStation)

DataPoint = _reflection.GeneratedProtocolMessageType('DataPoint', (_message.Message,), {
  'DESCRIPTOR' : _DATAPOINT,
  '__module__' : 'air.AirQuality_pb2'
  # @@protoc_insertion_point(class_scope:air_quality.DataPoint)
  })
_sym_db.RegisterMessage(DataPoint)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
  'DESCRIPTOR' : _ERROR,
  '__module__' : 'air.AirQuality_pb2'
  # @@protoc_insertion_point(class_scope:air_quality.Error)
  })
_sym_db.RegisterMessage(Error)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FeedHeaderStatic.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='FeedHeaderStatic.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x16\x46\x65\x65\x64HeaderStatic.proto\"d\n\x10\x46\x65\x65\x64HeaderStatic\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0e\n\x06\x61gency\x18\x02 \x01(\t\x12\x12\n\x04tags\x18\x03 \x03(\x0b\x32\x04.Tag\x12\x1b\n\x13lastUpdateTimestamp\x18\x04 \x01(\x04\"\"\n\x03Tag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\tb\x06proto3'
)




_FEEDHEADERSTATIC = _descriptor.Descriptor(
  name='FeedHeaderStatic',
  full_name='FeedHeaderStatic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='FeedHeaderStatic.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agency', full_name='FeedHeaderStatic.agency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='FeedHeaderStatic.tags', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastUpdateTimestamp', full_name='FeedHeaderStatic.lastUpdateTimestamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=126,
)


_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Tag.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Tag.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=162,
)

_FEEDHEADERSTATIC.fields_by_name['tags'].message_type = _TAG
DESCRIPTOR.message_types_by_name['FeedHeaderStatic'] = _FEEDHEADERSTATIC
DESCRIPTOR.message_types_by_name['Tag'] = _TAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedHeaderStatic = _reflection.GeneratedProtocolMessageType('FeedHeaderStatic', (_message.Message,), {
  'DESCRIPTOR' : _FEEDHEADERSTATIC,
  '__module__' : 'FeedHeaderStatic_pb2'
  # @@protoc_insertion_point(class_scope:FeedHeaderStatic)
  })
_sym_db.RegisterMessage(FeedHeaderStatic)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
  'DESCRIPTOR' : _TAG,
  '__module__' : 'FeedHeaderStatic_pb2'
  # @@protoc_insertion_point(class_scope:Tag)
  })
_sym_db.RegisterMessage(Tag)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FeedHeader.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='FeedHeader.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x10\x46\x65\x65\x64Header.proto\"\xb7\x01\n\nFeedHeader\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x32\n\x0eincrementality\x18\x02 \x01(\x0e\x32\x1a.FeedHeader.Incrementality\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12\x1b\n\x08provider\x18\x04 \x01(\x0b\x32\t.Provider\"4\n\x0eIncrementality\x12\x10\n\x0c\x46ULL_DATASET\x10\x00\x12\x10\n\x0c\x44IFFERENTIAL\x10\x01\"$\n\x08Provider\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\tb\x06proto3'
)



_FEEDHEADER_INCREMENTALITY = _descriptor.EnumDescriptor(
  name='Incrementality',
  full_name='FeedHeader.Incrementality',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FULL_DATASET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIFFERENTIAL', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=152,
  serialized_end=204,
)
_sym_db.RegisterEnumDescriptor(_FEEDHEADER_INCREMENTALITY)


_FEEDHEADER = _descriptor.Descriptor(
  name='FeedHeader',
  full_name='FeedHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='FeedHeader.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incrementality', full_name='FeedHeader.incrementality', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='FeedHeader.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provider', full_name='FeedHeader.provider', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDHEADER_INCREMENTALITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21,
  serialized_end=204,
)


_PROVIDER = _descriptor.Descriptor(
  name='Provider',
  full_name='Provider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Provider.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='Provider.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=242,
)

_FEEDHEADER.fields_by_name['incrementality'].enum_type = _FEEDHEADER_INCREMENTALITY
_FEEDHEADER.fields_by_name['provider'].message_type = _PROVIDER
_FEEDHEADER_INCREMENTALITY.containing_type = _FEEDHEADER
DESCRIPTOR.message_types_by_name['FeedHeader'] = _FEEDHEADER
DESCRIPTOR.message_types_by_name['Provider'] = _PROVIDER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedHeader = _reflection.GeneratedProtocolMessageType('FeedHeader', (_message.Message,), {
  'DESCRIPTOR' : _FEEDHEADER,
  '__module__' : 'FeedHeader_pb2'
  # @@protoc_insertion_point(class_scope:FeedHeader)
  })
_sym_db.RegisterMessage(FeedHeader)

Provider = _reflection.GeneratedProtocolMessageType('Provider', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDER,
  '__module__' : 'FeedHeader_pb2'
  # @@protoc_insertion_point(class_scope:Provider)
  })
_sym_db.RegisterMessage(Provider)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: solar-power-production/SolarPowerProduction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import FeedHeader_pb2 as FeedHeader__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='solar-power-production/SolarPowerProduction.proto',
  package='solar_production',
  syntax='proto3',
  serialized_options=b'\n\032io.pravah.solar.production',
  serialized_pb=b'\n1solar-power-production/SolarPowerProduction.proto\x12\x10solar_production\x1a\x10\x46\x65\x65\x64Header.proto\"[\n\x0b\x46\x65\x65\x64Message\x12\x1b\n\x06header\x18\x01 \x01(\x0b\x32\x0b.FeedHeader\x12/\n\x08stations\x18\x02 \x03(\x0b\x32\x1d.solar_production.FeedStation\"\xfe\x01\n\x0b\x46\x65\x65\x64Station\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x06status\x18\x02 \x01(\x0b\x32\x18.solar_production.Status\x12N\n\x19powerGenerationParameters\x18\x03 \x01(\x0b\x32+.solar_production.PowerGenerationParameters\x12$\n\x04info\x18\x04 \x01(\x0b\x32\x16.solar_production.Info\x12\x30\n\x0cinverterList\x18\x05 \x03(\x0b\x32\x1a.solar_production.Inverter\x12\x11\n\ttimestamp\x18\x06 \x01(\x04\"\xc1\x02\n\x08Inverter\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x06status\x18\x02 \x01(\x0b\x32\x18.solar_production.Status\x12:\n\x0fphaseComponents\x18\x03 \x03(\x0b\x32!.solar_production.PhaseComponents\x12:\n\x0fsolarPanelGroup\x18\x04 \x03(\x0b\x32!.solar_production.SolarPanelGroup\x12N\n\x19powerGenerationParameters\x18\x05 \x01(\x0b\x32+.solar_production.PowerGenerationParameters\x12$\n\x04info\x18\x06 \x01(\x0b\x32\x16.solar_production.Info\x12\x11\n\ttimestamp\x18\x07 \x01(\x04\"\x97\x01\n\x19PowerGenerationParameters\x12\x1a\n\x12\x63urrentPowerOutput\x18\x01 \x01(\x02\x12\x1b\n\x13powerGeneratedToday\x18\x02 \x01(\x02\x12\x13\n\x0birradiation\x18\x03 \x01(\x02\x12\x11\n\twindspeed\x18\x04 \x01(\x02\x12\x19\n\x11moduleTemperature\x18\x05 \x01(\x02\"Y\n\x04Info\x12\x15\n\rpowerCapacity\x18\x01 \x01(\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n\x08location\x18\x03 \x01(\x0b\x32\x1a.solar_production.Location\"\xa9\x01\n\x0fPhaseComponents\x12@\n\x12\x65lectricComponents\x18\x01 \x01(\x0b\x32$.solar_production.ElectricComponents\x12\x36\n\x05phase\x18\x02 \x01(\x0e\x32\'.solar_production.PhaseComponents.Phase\"\x1c\n\x05Phase\x12\x05\n\x01\x42\x10\x00\x12\x05\n\x01R\x10\x01\x12\x05\n\x01Y\x10\x02\"\x87\x01\n\x0fSolarPanelGroup\x12@\n\x12\x65lectricComponents\x18\x01 \x01(\x0b\x32$.solar_production.ElectricComponents\x12\x12\n\npanelCount\x18\x02 \x01(\r\x12\x1e\n\x16\x61verageGroupModuleTemp\x18\x03 \x01(\x02\"X\n\x12\x45lectricComponents\x12\r\n\x05power\x18\x01 \x01(\x01\x12\x0f\n\x07voltage\x18\x02 \x01(\x01\x12\x0f\n\x07\x63urrent\x18\x03 \x01(\x01\x12\x11\n\tfrequency\x18\x04 \x01(\x01\"/\n\x08Location\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\"r\n\x06Status\x12-\n\x05state\x18\x01 \x01(\x0e\x32\x1e.solar_production.Status.State\x12\x0f\n\x07message\x18\x02 \x01(\t\"(\n\x05State\x12\r\n\tCONNECTED\x10\x00\x12\x10\n\x0c\x44ISCONNECTED\x10\x01\"$\n\x05\x45rror\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x42\x1c\n\x1aio.pravah.solar.productionb\x06proto3'
  ,
  dependencies=[FeedHeader__pb2.DESCRIPTOR,])



_PHASECOMPONENTS_PHASE = _descriptor.EnumDescriptor(
  name='Phase',
  full_name='solar_production.PhaseComponents.Phase',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='B', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='R', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Y', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1150,
  serialized_end=1178,
)
_sym_db.RegisterEnumDescriptor(_PHASECOMPONENTS_PHASE)

_STATUS_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='solar_production.Status.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONNECTED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISCONNECTED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1531,
  serialized_end=1571,
)
_sym_db.RegisterEnumDescriptor(_STATUS_STATE)


_FEEDMESSAGE = _descriptor.Descriptor(
  name='FeedMessage',
  full_name='solar_production.FeedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='solar_production.FeedMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stations', full_name='solar_production.FeedMessage.stations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=180,
)


_FEEDSTATION = _descriptor.Descriptor(
  name='FeedStation',
  full_name='solar_production.FeedStation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='solar_production.FeedStation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='solar_production.FeedStation.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='powerGenerationParameters', full_name='solar_production.FeedStation.powerGenerationParameters', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='solar_production.FeedStation.info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverterList', full_name='solar_production.FeedStation.inverterList', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='solar_production.FeedStation.timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=437,
)


_INVERTER = _descriptor.Descriptor(
  name='Inverter',
  full_name='solar_production.Inverter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='solar_production.Inverter.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='solar_production.Inverter.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phaseComponents', full_name='solar_production.Inverter.phaseComponents', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='solarPanelGroup', full_name='solar_production.Inverter.solarPanelGroup', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='powerGenerationParameters', full_name='solar_production.Inverter.powerGenerationParameters', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='solar_production.Inverter.info', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='solar_production.Inverter.timestamp', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=761,
)


_POWERGENERATIONPARAMETERS = _descriptor.Descriptor(
  name='PowerGenerationParameters',
  full_name='solar_production.PowerGenerationParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentPowerOutput', full_name='solar_production.PowerGenerationParameters.currentPowerOutput', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='powerGeneratedToday', full_name='solar_production.PowerGenerationParameters.powerGeneratedToday', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='irradiation', full_name='solar_production.PowerGenerationParameters.irradiation', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='windspeed', full_name='solar_production.PowerGenerationParameters.windspeed', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='moduleTemperature', full_name='solar_production.PowerGenerationParameters.moduleTemperature', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=764,
  serialized_end=915,
)


_INFO = _descriptor.Descriptor(
  name='Info',
  full_name='solar_production.Info',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='powerCapacity', full_name='solar_production.Info.powerCapacity', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='solar_production.Info.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='solar_production.Info.location', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=917,
  serialized_end=1006,
)


_PHASECOMPONENTS = _descriptor.Descriptor(
  name='PhaseComponents',
  full_name='solar_production.PhaseComponents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='electricComponents', full_name='solar_production.PhaseComponents.electricComponents', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='solar_production.PhaseComponents.phase', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PHASECOMPONENTS_PHASE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1009,
  serialized_end=1178,
)


_SOLARPANELGROUP = _descriptor.Descriptor(
  name='SolarPanelGroup',
  full_name='solar_production.SolarPanelGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='electricComponents', full_name='solar_production.SolarPanelGroup.electricComponents', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='panelCount', full_name='solar_production.SolarPanelGroup.panelCount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='averageGroupModuleTemp', full_name='solar_production.SolarPanelGroup.averageGroupModuleTemp', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1181,
  serialized_end=1316,
)


_ELECTRICCOMPONENTS = _descriptor.Descriptor(
  name='ElectricComponents',
  full_name='solar_production.ElectricComponents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='power', full_name='solar_production.ElectricComponents.power', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voltage', full_name='solar_production.ElectricComponents.voltage', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current', full_name='solar_production.ElectricComponents.current', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='solar_production.ElectricComponents.frequency', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1318,
  serialized_end=1406,
)


_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='solar_production.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='solar_production.Location.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='solar_production.Location.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1408,
  serialized_end=1455,
)


_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='solar_production.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='solar_production.Status.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='solar_production.Status.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATUS_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1457,
  serialized_end=1571,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='solar_production.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='solar_production.Error.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='solar_production.Error.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1573,
  serialized_end=1609,
)

_FEEDMESSAGE.fields_by_name['header'].message_type = FeedHeader__pb2._FEEDHEADER
_FEEDMESSAGE.fields_by_name['stations'].message_type = _FEEDSTATION
_FEEDSTATION.fields_by_name['status'].message_type = _STATUS
_FEEDSTATION.fields_by_name['powerGenerationParameters'].message_type = _POWERGENERATIONPARAMETERS
_FEEDSTATION.fields_by_name['info'].message_type = _INFO
_FEEDSTATION.fields_by_name['inverterList'].message_type = _INVERTER
_INVERTER.fields_by_name['status'].message_type = _STATUS
_INVERTER.fields_by_name['phaseComponents'].message_type = _PHASECOMPONENTS
_INVERTER.fields_by_name['solarPanelGroup'].message_type = _SOLARPANELGROUP
_INVERTER.fields_by_name['powerGenerationParameters'].message_type = _POWERGENERATIONPARAMETERS
_INVERTER.fields_by_name['info'].message_type = _INFO
_INFO.fields_by_name['location'].message_type = _LOCATION
_PHASECOMPONENTS.fields_by_name['electricComponents'].message_type = _ELECTRICCOMPONENTS
_PHASECOMPONENTS.fields_by_name['phase'].enum_type = _PHASECOMPONENTS_PHASE
_PHASECOMPONENTS_PHASE.containing_type = _PHASECOMPONENTS
_SOLARPANELGROUP.fields_by_name['electricComponents'].message_type = _ELECTRICCOMPONENTS
_STATUS.fields_by_name['state'].enum_type = _STATUS_STATE
_STATUS_STATE.containing_type = _STATUS
DESCRIPTOR.message_types_by_name['FeedMessage'] = _FEEDMESSAGE
DESCRIPTOR.message_types_by_name['FeedStation'] = _FEEDSTATION
DESCRIPTOR.message_types_by_name['Inverter'] = _INVERTER
DESCRIPTOR.message_types_by_name['PowerGenerationParameters'] = _POWERGENERATIONPARAMETERS
DESCRIPTOR.message_types_by_name['Info'] = _INFO
DESCRIPTOR.message_types_by_name['PhaseComponents'] = _PHASECOMPONENTS
DESCRIPTOR.message_types_by_name['SolarPanelGroup'] = _SOLARPANELGROUP
DESCRIPTOR.message_types_by_name['ElectricComponents'] = _ELECTRICCOMPONENTS
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMessage = _reflection.GeneratedProtocolMessageType('FeedMessage', (_message.Message,), {
  'DESCRIPTOR' : _FEEDMESSAGE,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.FeedMessage)
  })
_sym_db.RegisterMessage(FeedMessage)

FeedStation = _reflection.GeneratedProtocolMessageType('FeedStation', (_message.Message,), {
  'DESCRIPTOR' : _FEEDSTATION,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.FeedStation)
  })
_sym_db.RegisterMessage(FeedStation)

Inverter = _reflection.GeneratedProtocolMessageType('Inverter', (_message.Message,), {
  'DESCRIPTOR' : _INVERTER,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.Inverter)
  })
_sym_db.RegisterMessage(Inverter)

PowerGenerationParameters = _reflection.GeneratedProtocolMessageType('PowerGenerationParameters', (_message.Message,), {
  'DESCRIPTOR' : _POWERGENERATIONPARAMETERS,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.PowerGenerationParameters)
  })
_sym_db.RegisterMessage(PowerGenerationParameters)

Info = _reflection.GeneratedProtocolMessageType('Info', (_message.Message,), {
  'DESCRIPTOR' : _INFO,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.Info)
  })
_sym_db.RegisterMessage(Info)

PhaseComponents = _reflection.GeneratedProtocolMessageType('PhaseComponents', (_message.Message,), {
  'DESCRIPTOR' : _PHASECOMPONENTS,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.PhaseComponents)
  })
_sym_db.RegisterMessage(PhaseComponents)

SolarPanelGroup = _reflection.GeneratedProtocolMessageType('SolarPanelGroup', (_message.Message,), {
  'DESCRIPTOR' : _SOLARPANELGROUP,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.SolarPanelGroup)
  })
_sym_db.RegisterMessage(SolarPanelGroup)

ElectricComponents = _reflection.GeneratedProtocolMessageType('ElectricComponents', (_message.Message,), {
  'DESCRIPTOR' : _ELECTRICCOMPONENTS,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.ElectricComponents)
  })
_sym_db.RegisterMessage(ElectricComponents)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.Location)
  })
_sym_db.RegisterMessage(Location)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
  'DESCRIPTOR' : _STATUS,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.Status)
  })
_sym_db.RegisterMessage(Status)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
  'DESCRIPTOR' : _ERROR,
  '__module__' : 'solar_power_production.SolarPowerProduction_pb2'
  # @@protoc_insertion_point(class_scope:solar_production.Error)
  })
_sym_db.RegisterMessage(Error)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: health/Covid19District.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import FeedHeader_pb2 as FeedHeader__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='health/Covid19District.proto',
  package='health_covid_district',
  syntax='proto3',
  serialized_options=b'\n\037io.pravah.health.covid_district',
  serialized_pb=b'\n\x1chealth/Covid19District.proto\x12\x15health_covid_district\x1a\x10\x46\x65\x65\x64Header.proto\"]\n\x0b\x46\x65\x65\x64Message\x12\x1b\n\x06header\x18\x01 \x01(\x0b\x32\x0b.FeedHeader\x12\x31\n\tcountries\x18\x02 \x03(\x0b\x32\x1e.health_covid_district.Country\"r\n\x07\x43ountry\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12+\n\x05stats\x18\x02 \x01(\x0b\x32\x1c.health_covid_district.Stats\x12,\n\x06states\x18\x03 \x03(\x0b\x32\x1c.health_covid_district.State\"v\n\x05State\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12+\n\x05stats\x18\x02 \x01(\x0b\x32\x1c.health_covid_district.Stats\x12\x32\n\tdistricts\x18\x03 \x03(\x0b\x32\x1f.health_covid_district.District\"y\n\x08\x44istrict\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12+\n\x05stats\x18\x02 \x01(\x0b\x32\x1c.health_covid_district.Stats\x12\x32\n\thospitals\x18\x03 \x03(\x0b\x32\x1f.health_covid_district.Hospital\"w\n\x08Hospital\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12+\n\x05stats\x18\x02 \x01(\x0b\x32\x1c.health_covid_district.Stats\x12\x30\n\x08patients\x18\x03 \x03(\x0b\x32\x1e.health_covid_district.Patient\"|\n\x05Stats\x12\x1a\n\x12totalPositiveCases\x18\x01 \x01(\r\x12\x1b\n\x13\x61\x63tivePositiveCases\x18\x02 \x01(\r\x12\x12\n\ncuredCases\x18\x03 \x01(\r\x12\x12\n\ndeathCases\x18\x04 \x01(\r\x12\x12\n\notherCases\x18\x05 \x01(\r\"f\n\x07Patient\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0b\n\x03\x61ge\x18\x02 \x01(\r\x12\x0e\n\x06gender\x18\x03 \x01(\t\x12\x16\n\x0einfectedOnDate\x18\x04 \x01(\x04\x12\x18\n\x10infectedFromUUID\x18\x05 \x03(\tB!\n\x1fio.pravah.health.covid_districtb\x06proto3'
  ,
  dependencies=[FeedHeader__pb2.DESCRIPTOR,])




_FEEDMESSAGE = _descriptor.Descriptor(
  name='FeedMessage',
  full_name='health_covid_district.FeedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='health_covid_district.FeedMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='countries', full_name='health_covid_district.FeedMessage.countries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=166,
)


_COUNTRY = _descriptor.Descriptor(
  name='Country',
  full_name='health_covid_district.Country',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='health_covid_district.Country.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='health_covid_district.Country.stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='states', full_name='health_covid_district.Country.states', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=282,
)


_STATE = _descriptor.Descriptor(
  name='State',
  full_name='health_covid_district.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='health_covid_district.State.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='health_covid_district.State.stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='districts', full_name='health_covid_district.State.districts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=402,
)


_DISTRICT = _descriptor.Descriptor(
  name='District',
  full_name='health_covid_district.District',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='health_covid_district.District.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='health_covid_district.District.stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hospitals', full_name='health_covid_district.District.hospitals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=525,
)


_HOSPITAL = _descriptor.Descriptor(
  name='Hospital',
  full_name='health_covid_district.Hospital',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='health_covid_district.Hospital.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='health_covid_district.Hospital.stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='patients', full_name='health_covid_district.Hospital.patients', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=646,
)


_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='health_covid_district.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='totalPositiveCases', full_name='health_covid_district.Stats.totalPositiveCases', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activePositiveCases', full_name='health_covid_district.Stats.activePositiveCases', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curedCases', full_name='health_covid_district.Stats.curedCases', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deathCases', full_name='health_covid_district.Stats.deathCases', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otherCases', full_name='health_covid_district.Stats.otherCases', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=648,
  serialized_end=772,
)


_PATIENT = _descriptor.Descriptor(
  name='Patient',
  full_name='health_covid_district.Patient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='health_covid_district.Patient.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='age', full_name='health_covid_district.Patient.age', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gender', full_name='health_covid_district.Patient.gender', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infectedOnDate', full_name='health_covid_district.Patient.infectedOnDate', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infectedFromUUID', full_name='health_covid_district.Patient.infectedFromUUID', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=876,
)

_FEEDMESSAGE.fields_by_name['header'].message_type = FeedHeader__pb2._FEEDHEADER
_FEEDMESSAGE.fields_by_name['countries'].message_type = _COUNTRY
_COUNTRY.fields_by_name['stats'].message_type = _STATS
_COUNTRY.fields_by_name['states'].message_type = _STATE
_STATE.fields_by_name['stats'].message_type = _STATS
_STATE.fields_by_name['districts'].message_type = _DISTRICT
_DISTRICT.fields_by_name['stats'].message_type = _STATS
_DISTRICT.fields_by_name['hospitals'].message_type = _HOSPITAL
_HOSPITAL.fields_by_name['stats'].message_type = _STATS
_HOSPITAL.fields_by_name['patients'].message_type = _PATIENT
DESCRIPTOR.message_types_by_name['FeedMessage'] = _FEEDMESSAGE
DESCRIPTOR.message_types_by_name['Country'] = _COUNTRY
DESCRIPTOR.message_types_by_name['State'] = _STATE
DESCRIPTOR.message_types_by_name['District'] = _DISTRICT
DESCRIPTOR.message_types_by_name['Hospital'] = _HOSPITAL
DESCRIPTOR.message_types_by_name['Stats'] = _STATS
DESCRIPTOR.message_types_by_name['Patient'] = _PATIENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMessage = _reflection.GeneratedProtocolMessageType('FeedMessage', (_message.Message,), {
  'DESCRIPTOR' : _FEEDMESSAGE,
  '__module__' : 'health.Covid19District_pb2'
  # @@protoc_insertion_point(class_scope:health_covid_district.FeedMessage)
  })
_sym_db.RegisterMessage(FeedMessage)

Country = _reflection.GeneratedProtocolMessageType('Country', (_message.Message,), {
  'DESCRIPTOR' : _COUNTRY,
  '__module__' : 'health.Covid19District_pb2'
  # @@protoc_insertion_point(class_scope:health_covid_district.Country)
  })
_sym_db.RegisterMessage(Country)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
  'DESCRIPTOR' : _STATE,
  '__module__' : 'health.Covid19District_pb2'
  # @@protoc_insertion_point(class_scope:health_covid_district.State)
  })
_sym_db.RegisterMessage(State)

District = _reflection.GeneratedProtocolMessageType('District', (_message.Message,), {
  'DESCRIPTOR' : _DISTRICT,
  '__module__' : 'health.Covid19District_pb2'
  # @@protoc_insertion_point(class_scope:health_covid_district.District)
  })
_sym_db.RegisterMessage(District)

Hospital = _reflection.GeneratedProtocolMessageType('Hospital', (_message.Message,), {
  'DESCRIPTOR' : _HOSPITAL,
  '__module__' : 'health.Covid19District_pb2'
  # @@protoc_insertion_point(class_scope:health_covid_district.Hospital)
  })
_sym_db.RegisterMessage(Hospital)

Stats = _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), {
  'DESCRIPTOR' : _STATS,
  '__module__' : 'health.Covid19District_pb2'
  # @@protoc_insertion_point(class_scope:health_covid_district.Stats)
  })
_sym_db.RegisterMessage(Stats)

Patient = _reflection.GeneratedProtocolMessageType('Patient', (_message.Message,), {
  'DESCRIPTOR' : _PATIENT,
  '__module__' : 'health.Covid19District_pb2'
  # @@protoc_insertion_point(class_scope:health_covid_district.Patient)
  })
_sym_db.RegisterMessage(Patient)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import setuptools

setuptools.setup(
    name="pravah_protocols",
    version="0.0.5",
    author="Abhishek Upperwal",
    author_email="mesh@soket.in",
    description="Proto generated for all protocols",
    url="https://github.com/pravahio",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires = [
        'protobuf'
    ]
)